==> haskell-unix-compat-0.7.4.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unix-compat
version:              0.7.4.1
visibility:           public
id:                   unix-compat-0.7.4.1-IVg4e2FKApqEytJ5iwZzXw
key:                  unix-compat-0.7.4.1-IVg4e2FKApqEytJ5iwZzXw
license:              BSD-3-Clause
maintainer:           https://github.com/haskell-pkg-janitors
author:
    Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan

homepage:             https://github.com/haskell-pkg-janitors/unix-compat
synopsis:             Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.

category:             System
abi:                  6f2ad4a12172c86830d4e658b87a661b
exposed:              True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Process
    System.PosixCompat.Temp System.PosixCompat.Time
    System.PosixCompat.Types System.PosixCompat.Unistd

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-compat
hs-libraries:         HSunix-compat-0.7.4.1-IVg4e2FKApqEytJ5iwZzXw
include-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4.1/include
includes:             HsUnixCompat.h
depends:              base-4.17.2.1 unix-2.7.3
haddock-interfaces:   /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html:         /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unix-compat-0.7.4.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unix-compat
version:              0.7.4.1
visibility:           public
id:                   unix-compat-0.7.4.1-ISYORPhqblp3hlkoU2fe45
key:                  unix-compat-0.7.4.1-ISYORPhqblp3hlkoU2fe45
license:              BSD-3-Clause
maintainer:           https://github.com/haskell-pkg-janitors
author:
    Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan

homepage:             https://github.com/haskell-pkg-janitors/unix-compat
synopsis:             Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.

category:             System
abi:                  495f13188e046e9a1d5cdf24688103ac
exposed:              True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Process
    System.PosixCompat.Temp System.PosixCompat.Time
    System.PosixCompat.Types System.PosixCompat.Unistd

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-compat
hs-libraries:         HSunix-compat-0.7.4.1-ISYORPhqblp3hlkoU2fe45
include-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4.1/include
includes:             HsUnixCompat.h
depends:              base-4.17.2.1 unix-2.7.3
haddock-interfaces:   /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html:         /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
